parsedatetime.parsedatetime

Package parsedatetime :: Module parsedatetime |
[hide private]
[frames] | no frames]

# Module parsedatetime

source code
Parse human-readable date/time text.

Classes | [hide private]
`` | Calendar A collection of routines to input, parse and manipulate date and times.

Functions | [hide private]
`` | _extract_date(m)
`` | _extract_time(m)
`` | _parse_date_w3dtf(dateString)
`` | _parse_date_rfc822(dateString) Parse an RFC822, RFC1123, RFC2822, or asctime-style date

Variables | [hide private]
`` | __license__ = `'\nCopyright (c) 2004-2007 Mike Taylor\nCopyright (c...`
`` | _debug = `False`
`` | _additional_timezones = `{'ET': -500, 'MT': -700, 'AT': -400, 'PT': -800, 'CT...`

Function Details | [hide private]

### _extract_date(m) | source code
None

### _extract_time(m) | source code
None

### _parse_date_w3dtf(dateString) | source code
None

### _parse_date_rfc822(dateString) | source code
Parse an RFC822, RFC1123, RFC2822, or asctime-style date

Variables Details | [hide private]

    ### __license__ None Value:
        '''
        Copyright (c) 2004-2007 Mike Taylor
        Copyright (c) 2007 Darshana Chhajed
        All rights reserved.

        Licensed under the Apache License, Version 2.0 (the "License");
        you may not use this file except in compliance with the License.
        You may obtain a copy of the License at
        ...

    ### _debug None Value:
        False

    ### _additional_timezones None Value:
        {'ET': -500, 'MT': -700, 'AT': -400, 'PT': -800, 'CT': -600}